@@ -8,10 +8,8 @@ use sessions::*;
 
 #[tokio::test]
 async fn redis() -> Result<()> {
-    let storage = Arc::new(RedisStorage::new(RedisClient::open("redis://127.0.0.1")?));
-
     fn generate() -> String {
-        nano_id::base64(32)
+        nano_id::base64::<32>()
     }
 
     fn verify(sid: &str) -> bool {
@@ -20,7 +18,7 @@ async fn redis() -> Result<()> {
 
     let config = Arc::new(Config {
         cookie: CookieOptions::new(),
-        storage: storage.clone(),
+        storage: RedisStorage::new(RedisClient::open("unix:///tmp/redis.sock")?),
         generate: Box::new(generate),
         verify: Box::new(verify),
     });
@@ -48,7 +46,7 @@ async fn redis() -> Result<()> {
 
     let mut session = Session::new(&id, 0, config.clone());
 
-    if let Some(data) = storage.get(&id).await? {
+    if let Some(data) = config.get(&id).await? {
         session.set_data(data)?;
     }
 
